==> zio-aws-config_3-5.17.152.1-sources.jar: zio/aws/config/model/FailedRemediationExceptionBatch.scala <==
package zio.aws.config.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class FailedRemediationExceptionBatch(
    failureMessage: Option[String] = None,
    failedItems: Option[Iterable[zio.aws.config.model.RemediationException]] =
      None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.config.model.FailedRemediationExceptionBatch = {
    import FailedRemediationExceptionBatch.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.config.model.FailedRemediationExceptionBatch
      .builder()
      .optionallyWith(failureMessage.map(value => value: java.lang.String))(
        _.failureMessage
      )
      .optionallyWith(
        failedItems.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.failedItems)
      .build()
  }
  def asReadOnly
      : zio.aws.config.model.FailedRemediationExceptionBatch.ReadOnly =
    zio.aws.config.model.FailedRemediationExceptionBatch.wrap(buildAwsValue())
}
object FailedRemediationExceptionBatch {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.config.model.FailedRemediationExceptionBatch
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.config.model.FailedRemediationExceptionBatch =
      zio.aws.config.model.FailedRemediationExceptionBatch(
        failureMessage.map(value => value),
        failedItems.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def failureMessage: Option[String]
    def failedItems
        : Option[List[zio.aws.config.model.RemediationException.ReadOnly]]
    def getFailureMessage: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("failureMessage", failureMessage)
    def getFailedItems: ZIO[Any, AwsError, List[
      zio.aws.config.model.RemediationException.ReadOnly
    ]] = AwsError.unwrapOptionField("failedItems", failedItems)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.config.model.FailedRemediationExceptionBatch
  ) extends zio.aws.config.model.FailedRemediationExceptionBatch.ReadOnly {
    override val failureMessage: Option[String] =
      scala.Option(impl.failureMessage()).map(value => value: String)
    override val failedItems
        : Option[List[zio.aws.config.model.RemediationException.ReadOnly]] =
      scala
        .Option(impl.failedItems())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.config.model.RemediationException.wrap(item)
          }.toList
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.config.model.FailedRemediationExceptionBatch
  ): zio.aws.config.model.FailedRemediationExceptionBatch.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-config_3-5.17.267.1-sources.jar: zio/aws/config/model/FailedRemediationExceptionBatch.scala <==
package zio.aws.config.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class FailedRemediationExceptionBatch(
    failureMessage: Optional[String] = Optional.Absent,
    failedItems: Optional[Iterable[zio.aws.config.model.RemediationException]] =
      Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.config.model.FailedRemediationExceptionBatch = {
    import FailedRemediationExceptionBatch.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.config.model.FailedRemediationExceptionBatch
      .builder()
      .optionallyWith(failureMessage.map(value => value: java.lang.String))(
        _.failureMessage
      )
      .optionallyWith(
        failedItems.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.failedItems)
      .build()
  }
  def asReadOnly
      : zio.aws.config.model.FailedRemediationExceptionBatch.ReadOnly =
    zio.aws.config.model.FailedRemediationExceptionBatch.wrap(buildAwsValue())
}
object FailedRemediationExceptionBatch {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.config.model.FailedRemediationExceptionBatch
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.config.model.FailedRemediationExceptionBatch =
      zio.aws.config.model.FailedRemediationExceptionBatch(
        failureMessage.map(value => value),
        failedItems.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def failureMessage: Optional[String]
    def failedItems
        : Optional[List[zio.aws.config.model.RemediationException.ReadOnly]]
    def getFailureMessage: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("failureMessage", failureMessage)
    def getFailedItems: ZIO[Any, AwsError, List[
      zio.aws.config.model.RemediationException.ReadOnly
    ]] = AwsError.unwrapOptionField("failedItems", failedItems)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.config.model.FailedRemediationExceptionBatch
  ) extends zio.aws.config.model.FailedRemediationExceptionBatch.ReadOnly {
    override val failureMessage: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.failureMessage())
      .map(value => value: String)
    override val failedItems
        : Optional[List[zio.aws.config.model.RemediationException.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.failedItems())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.config.model.RemediationException.wrap(item)
          }.toList
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.config.model.FailedRemediationExceptionBatch
  ): zio.aws.config.model.FailedRemediationExceptionBatch.ReadOnly =
    new Wrapper(impl)
}
